#
# spec file for package python-python-rtmidi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-python-rtmidi
Version:        1.5.8
Release:        2.3
Summary:        Python binding for the RtMidi C++ library
License:        MIT
URL:            https://spotlightkid.github.io/python-rtmidi/
Source:         https://files.pythonhosted.org/packages/source/p/python-rtmidi/python_rtmidi-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module meson-python}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  c++_compiler
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(jack)
BuildRequires:  python(abi) > 3.8
%python_subpackages

%description
RtMidi is a set of C++ classes which provides an API for realtime
MIDI I/O across Linux (ALSA & JACK), macOS (CoreMIDI & JACK),
and Windows (MultiMedia System) operating systems.

python-rtmidi is a Python binding for RtMidi implemented using
Cython and provides a thin wrapper around the RtMidi C++ interface.
The API is basically the same as the C++ one but with the naming
scheme of classes, methods and parameters adapted to the Python
PEP-8 conventions and requirements of the Python package naming
structure.

%prep
%setup -q -n python_rtmidi-%{version}
sed -i 's,/usr/bin/env python,%{_bindir}/%{python_for_executables},' examples/*.py examples/*/*.py
rm src/_rtmidi.cpp

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

# not running tests since they require working JACK/ALSA,
# which cannot be provided on OBS workers

%files %{python_files}
%license LICENSE.md
%doc AUTHORS.md CHANGELOG.md README.md
%doc examples
%{python_sitearch}/rtmidi
%{python_sitearch}/python_rtmidi-%{version}.dist-info

%changelog
* Mon Jul  8 2024 Steve Kowalik <steven.kowalik@suse.com>
- Remove upper bound on Cython.
* Mon Dec 11 2023 Mia Herkt <mia@0x0.st>
- Update to 1.5.8
  * Removed obsolete Python 2 compatibility code in the _rtmidi
    module and references to Python 2 unicode type in its
    docstrings.
* Mon Nov  6 2023 Mia Herkt <mia@0x0.st>
- Omit html docs due to hostile build system
- Update to 1.5.7
  Fixes:
  * Fixed linting errors in `send_all.py` example.
    gh#SpotlightKid/python-rtmidi#184
  * Fixed (no)gil/except declarations on MIDI in callback and
    `MidiOut.sendMessage`.
    The GIL is acquired in any case for MIDI in callback and C++
    `sendMessage` call, since Cython needs to check for exceptions.
    Also remove wrong statement about the GIL being released in
    docstring for `send_message`.
    gh#SpotlightKid/python-rtmidi#185
  * Fixed errors and check for empty message correctly when passing
    an iter- or generator instead of a sequence to
    `MidiOut.send_message`.
    gh#SpotlightKid/python-rtmidi#186
    gh#SpotlightKid/python-rtmidi#188
- 1.5.6
  Fixes:
  * Fixed building with `meson-python` >= 0.14.0.
    gh#SpotlightKid/python-rtmidi#177
- 1.5.5
  * Bump minimum Python version to 3.8
  Fixes:
  * Fixed Cython compilation errors and warnings.
    gh#SpotlightKid/python-rtmidi#174
- 1.5.4
  Changes:
  * Added `send_all.py` script to examples.
    gh#SpotlightKid/python-rtmidi#167
- 1.5.3, 1.5.2
  Changes:
  * Updated `rtmidi` submodule.
    gh#SpotlightKid/python-rtmidi#156
- 1.5.1, 1.5.0
  Fixes:
  * Fixed memleak in `midiutils.list_{in,out}put_ports` function.
    gh#SpotlightKid/python-rtmidi#103
  * Fixed compilation with PyPy3.
  Documentation:
  * Clarified return types in docstrings.
  * Converted readme, changelog, authors, and install docs to
    Markdown.
* Tue Jun 27 2023 Edgar Aichinger <edogawa@aon.at>
- remove src/_rtmidi.cpp to let it be regenerated, to allow for python 3.11 flavour
* Tue Feb 21 2023 Daniel Garcia <daniel.garcia@suse.com>
- Skip python 3.11, not supported yet gh#SpotlightKid/python-rtmidi#115
* Wed Jun 23 2021 Mia Herkt <mia@0x0.st>
- Update to 1.4.9
  Changes:
  * Synced with upstream RtMidi_
    (fixes gh#SpotlightKid/python-rtmidi#89).
- Changes in 1.4.8:
  Fixes:
  * Fixed command line parsing in ``midiclock.py`` example script.
  * Fixed Windows builds on AppVeyor CI.
  Changes:
  * Release GIL in ``MidiOut.send_message`` so that on backend APIs
    where this operation is blocking (``WINDOWS_MM``), multiple
    Python threads using this method on different ``MidiOut``
    instances can run concurently.
* Tue Feb  2 2021 Mia Herkt <mia@0x0.st>
- Update to 1.4.7
  Fixes:
  * Fixed compiler deprecation warning about PyEval_InitThreads
    on Python 3.9+.
  Examples:
  * Added send_sysex and send_sysex_file example scripts.
* Sun Jan 24 2021 Mia Herkt <mia@0x0.st>
- Fix package build failure due to -doc package not being marked
  with %%python_files
* Thu Oct 15 2020 Mia Herkt <mia@0x0.st>
- Update to 1.4.6
  * Declare/document Python 3.9 support
  * Drop official support for Python 3.5
* Sun Oct 11 2020 Mia Herkt <mia@0x0.st>
- Update to 1.4.5
  * Fixed error when trying to import version number from
    ``rtmidi.release`` when Python is running with ``-OO``
    optimization enabled.
* Mon Jul 20 2020 Mia Herkt <mia@0x0.st>
- Fix rpmlint warnings
- Update to 1.4.2
  Enhancements:
  * Added more helpful aliases for MIDI events/controllers
    constants
  Examples:
  * Added ccstore advanced example to show how to remember last
    seen controller change values
* Mon Jun 22 2020 Mia Herkt <mia@0x0.st>
- init, 1.4.1
